<?php

// PHP function to display a JavaScript-based animation of PNG files.
//
// Copyright (C) 2006-2012 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU Affero
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with this software; see the file "license.txt".
// If not, see <http://www.gnu.org/licenses/>.

// Started in 2006 for DyToComp. Last revision: February 17, 2012.


// Returns an array of (file)names with an n-digit number inserted.
// $prefix - the prefix of each name to appear before the number
// $suffix - the suffix of each name to appear after the number
// $min - the first number in the sequence
// $max - the first number after the sequence
// (generates numbers $min, $min + 1, ..., $max - 1)
function numbernames ($prefix, $suffix, $min, $max)
{
	$names = array ();
	for ($i = $min; $i < $max; ++ $i)
	{
		$number = "$i";
		$ten = 10;
		while ($ten < $max)
		{
			if ($i < $ten)
				$number = "0" . $number;
			$ten *= 10;
		}
		$names [$i] = $prefix . $number . $suffix;
	}
	return $names;
} /* numbernames */

// Returns a JavaScript part of the animation
// which must be placed in the "head" section of the HTML page.
// $name - a base name for the images and the animation to use in JavaScript
// $images - an array of consecutive image files of the animation
// $addresses - an array of addresses to move to upon click of a given image
// $delay - delay in milliseconds
// $loop - looping: 1 - smoothly around, -1 - there and back
function anim_script ($name, $images, $addresses, $delay, $loop)
{
	$loadimages = "";
	$setaddresses = "";
	$count = count ($images);
	$addrcount = count ($addresses);
	for ($i = 0; $i < $count; ++ $i)
	{
		$loadimages .= "img${name}[${i}]=new Image ();\n" .
			"img${name}[${i}].src=\"${images[$i]}\";\n";
		if ($i < $addrcount)
		{
			$setaddresses .= "addr${name}[${i}]=" .
				"\"${addresses[$i]}\";\n";
		}
	}
	$count1 = $count - 1;
	return <<< SCRIPT
<script type="text/javascript">
<!--
var img${name} = new Array (${count});
var addr${name} = new Array (${addrcount});
${loadimages}
${setaddresses}
var current${name} = -1;
var direction${name} = 1;
var loop${name} = ${loop};
var running${name} = true;
var naddr${name} = ${addrcount};
function anim${name} ()
{
	var delay = ${delay};
	if (running${name})
	{
		current${name} += direction${name};
		if (current${name} >= ${count})
			current${name} = 0;
		if ((loop${name} < 0) && (current${name} == ${count1}))
		{
			direction${name} = -1;
			delay = 5 * delay;
		}
		if ((loop${name} < 0) && (current${name} == 0))
		{
			direction${name} = 1;
			delay = 5 * delay;
		}
		document.images.imganim${name}.src =
			img${name}[current${name}].src;
	}
	setTimeout ("anim${name}()", delay);
}

function anim${name}toggle()
{
	running${name} = !running${name};
}

function click${name}()
{
	if ((current${name} >= 0) && (current${name} < naddr${name}))
		window.location.assign (addr${name}[current${name}]);
	else
		anim${name}toggle();
}

// -->
</script>
SCRIPT;
} /* anim_script */

// Returns an attribute to add to the "body" tag.
function anim_body ($name)
{
	return "onload=\"document.images.imganim${name}.src=" .
		"img${name}[0].src;anim${name}();return true\"";
} /* anim_body */

// Returns the HTML code for placing an animation image in the web page.
function anim_img ($name, $attributes = "")
{
	return <<<IMG
<a href="javascript:void(0)"
onmouseover="anim${name}toggle();return true"
onmouseout="anim${name}toggle();return true"
onclick="click${name}();return true"><img
name="imganim${name}" ${attributes}/></a>
IMG;
} /* anim_img */

?>