<?php

// PHP function to generate a full HTML pabe which shows phenotype classes.
//
// Copyright (C) 2006-2011 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU Affero
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with this software; see the file "license.txt".
// If not, see <http://www.gnu.org/licenses/>.

// Started in 2006. Last revision: April 18, 2011.


require ("template.php");
require ("imgtooltip.php");
require ("imgclick.php");
require ("animation.php");


// Returns a HTML page with the description of a phenotype class.
// $maxnum - the number of phenotype classes (class 0 = single boxes,
// classes 1, 2, ..., $maxnum - 1 = nonempty classes)
// $images - PNG images of all the classes (if any)
// $animbase - animation basename
// $samplecubes - sample cubes for each class (if any)
// $datatitles, $datavalues - arrays of additional data for each class
function classes ($maxnum, $images, $animbase, $samplecubes, $browserlink,
	$cubeimages, $datatitles, $datavalues)
{
	$number = array_key_exists ("class", $_REQUEST) ?
		$_REQUEST ["class"] : '';
	$point = img_coord (false);
	$width = array_key_exists ("width", $_REQUEST) ?
		$_REQUEST ["width"] : '';
	if ((count ($point) == 2) && ($width > 0))
		$number = $point [1] * $width + $point [0] + 1;
	if (empty ($number) && ($number !== '0') && ($number !== 0))
		$number = 1;
	if ($number >= $maxnum)
		$number = 0;
	elseif ($number < 0)
		$number = 0;
	$prevnum = ($number > 0) ? ($number - 1) : $maxnum;
	$nextnum = ($number < $maxnum - 1) ? ($number + 1) : 0;

	$title = ($number == 0) ? 
		"Trivial phenotype classes (single boxes)" :
		"Phenotype class no. ${number}";

	$imghtml = "";
	if (!empty ($images [$number]))
	{
		$image = $images [$number];
		$imghtml .= "<p align=\"center\">" .
			"<img src=\"${image}\" border=\"0\"/>" .
			"</p>\n";
	}

	$coord = $samplecubes [$number];
	if (count ($coord))
	{
		$box = "(" . join (",", $coord) . ")";
		$boxlink = $browserlink;
		for ($i = 0; $i < count ($coord); ++ $i)
			$boxlink .= ($i ? "&" : "?") . "p${i}=${coord[$i]}";
		$offset = count ($datatitles);
		$datatitles [$offset] = "Sample box";
		$datavalues [$offset] [$number] =
			"<a href=\"${boxlink}\">${box}</a>";
	}

	$data = "";
	for ($i = 0; $i < count ($datatitles); ++ $i)
	{
		if ($i == 0)
		{
			$data .= "<p align=\"center\"><table border=\"1\" " .
				"cellpadding=\"8\" cellspacing=\"0\">\n";
		}
		$datatitle = $datatitles [$i];
		$datavalue = $datavalues [$i] [$number];
		$data .= "<tr><td align=\"left\">$datatitle</td>\n" .
			"<td>$datavalue</td></tr>\n";
		if ($i == count ($datatitles) - 1)
			$data .= "</table></p>\n";
	}

	$cubeimg = "";
	if (count ($cubeimages) && count ($coord))
	{
		$cubeimg .= "<p align=\"center\">" .
			"<table border=\"1\" cellpadding=\"8\" " .
			"cellspacing=\"0\"><tr>\n";
		for ($i = 0; $i < count ($cubeimages); ++ $i)
		{
			$imgtitle = $cubeimages [$i] [0];
			$cubeimg .= "<td align=\"center\">" .
				"${imgtitle}</td>\n";
		}
		$cubeimg .= "</tr><tr>\n";
		for ($i = 0; $i < count ($cubeimages); ++ $i)
		{
			$imglink = $cubeimages [$i] [1] .
				join ($cubeimages [$i] [2], $coord) .
				$cubeimages [$i] [3];
			$cubeimg .= "<td align=\"center\" valign=\"top\">" .
				"<a href=\"${imglink}\">" .
				"<img src=\"${imglink}&max=400\" " .
				"border=\"0\"/>" .
				"</td>\n";
		}
		$cubeimg .= "</tr></table></p>\n";
	}

	if (!empty ($animbase))
	{
		$numtxt = "$number";
		if (($number < 10) && ($maxnum > 10))
			$numtxt = "0" . $numtxt;
		if (($number < 100) && ($maxnum > 100))
			$numtxt = "0" . $numtxt;
		if (($number < 1000) && ($maxnum > 1000))
			$numtxt = "0" . $numtxt;
		$animscript = anim_script ("pp",
			numbernames ("${animbase}${numtxt}p", ".png", 0, 36),
			array (), 100, 1);
		$animbody = anim_body ("pp");
		$animimg = "<p align=\"center\">" .
			anim_img ("pp", "border=\"0\"") . "</p>";
	}

	$html = html_begin ($title, $animscript, $animbody, false);
	$html .= <<< HTML
<h1>${title}</h1>
${imghtml}
${animimg}
${data}
${cubeimg}
<p align="center">&lt;&ndash;
<a href="?class=${prevnum}">[${prevnum}]</a>
&nbsp; &nbsp; &nbsp; [${number}] &nbsp; &nbsp; &nbsp;
<a href="?class=${nextnum}">[${nextnum}]</a>
&ndash;&gt;</p>
HTML;
	$html .= html_end ();
	return $html;
}

?>